@@ -25,6 +25,7 @@
 #include "QtScriptBackend.h"
 
 #include <KDebug>
+#include <KLocale>
 #include <QColor>
 #include <boost/weak_ptr.hpp>
 
@@ -62,12 +63,12 @@ void Pointer::setQpointer(PointerPtr q)
 void Pointer::initialize()
 {
     // register pointer at endpoints and connect to changes
-    d->from->registerOutPointer(getPointer());
-    d->to->registerInPointer(getPointer());
+    d->from->addPointer(getPointer());
+    d->to->addPointer(getPointer());
     updateRelativeIndex();
     connect(d->to.get(), SIGNAL(posChanged(QPointF)), this, SIGNAL(posChanged()));
     connect(d->from.get(), SIGNAL(pointerListChanged()), this, SLOT(updateRelativeIndex()));
-    connect(d->dataStructure.get(), SIGNAL(complexityChanged(bool)), this, SIGNAL(changed()));
+    connect(d->pointerType.get(), SIGNAL(directionChanged(PointerType::Direction)), this, SIGNAL(changed()));
     connect(d->from.get(), SIGNAL(posChanged(QPointF)), this, SIGNAL(posChanged()));
 
     // register properties and connect to changes
@@ -83,6 +84,8 @@ void Pointer::initialize()
             this, SLOT(renameDynamicProperty(QString,QString)));
     connect(d->pointerType.get(), SIGNAL(propertyDefaultValueChanged(QString)),
             this, SLOT(updateDynamicProperty(QString)));
+    connect(d->pointerType.get(), SIGNAL(visibilityChanged(bool)),
+            this, SLOT(setVisible(bool)));
     connect(d->pointerType.get(), SIGNAL(propertyVisibilityChanged(QString)),
             this, SLOT(updateDynamicProperty(QString)));
 }
@@ -209,6 +212,11 @@ PointerType::Direction Pointer::direction() const
     return d->pointerType->direction();
 }
 
+bool Pointer::isDirected() const
+{
+    return (d->pointerType->direction() == PointerType::Unidirectional);
+}
+
 void Pointer::setVisible(bool visible)
 {
     d->visible = visible;
@@ -267,10 +275,10 @@ void Pointer::removeDynamicProperty(const QString& property)
 
 void Pointer::updateDynamicProperty(const QString& property)
 {
-    if (this->property(property.toStdString().c_str()) == QVariant::Invalid
-        || this->property(property.toStdString().c_str()).toString().isEmpty()
+    if (this->property(property.toLatin1()) == QVariant::Invalid
+        || this->property(property.toLatin1()).toString().isEmpty()
     ) {
-        this->setProperty(property.toStdString().c_str(), d->pointerType->propertyDefaultValue(property));
+        this->setProperty(property.toLatin1(), d->pointerType->propertyDefaultValue(property));
     }
     emit propertyChanged(property);
 }
@@ -281,8 +289,8 @@ void Pointer::renameDynamicProperty(const QString& oldName, const QString& newNa
         kWarning() << "Property identifier \"" << newName << "\" is not valid: aborting";
         return;
     }
-    setProperty(newName.toStdString().c_str(), property(oldName.toStdString().c_str()));
-    setProperty(oldName.toStdString().c_str(), QVariant::Invalid);
+    setProperty(newName.toLatin1(), property(oldName.toLatin1()));
+    setProperty(oldName.toLatin1(), QVariant::Invalid);
 }
 
 QScriptValue Pointer::set_type(int pointerType)
